@@ -1,5 +1,5 @@
 // This is -*- C++ -*-
-// $Id: RealSet_smob.cpp,v 1.10 1999/05/28 17:05:05 trow Exp $
+// $Id: RealSet_smob.cpp,v 1.11 1999/07/09 19:45:15 trow Exp $
 
 /* 
  * RealSet_smob.cpp
@@ -482,6 +482,23 @@ GOOSE_PROC(anddar, "realset-anderson-darling",
   return gh_double2scm(x);
 }
 
+GOOSE_PROC(gmeanthresh, "realset-gmean-threshold",
+	   2,0,0, (SCM scm_rs, SCM scm_c))
+{
+  SCM_ASSERT(REALSET_P(scm_rs), scm_rs, SCM_ARG1, str_gmeanthresh);
+  SCM_ASSERT(gh_number_p(scm_c), scm_c, SCM_ARG2, str_gmeanthresh);
+
+  double c = gh_scm2double(scm_c);
+  SCM_ASSERT(c >= 0 && c <= 1, scm_c, SCM_OUTOFRANGE, str_gmeanthresh);
+  double x = 0;
+  try {
+    RealSet* rs = scm2realset(scm_rs);
+    x = goose_gmean_threshold(*rs, c);
+  } GOOSE_CATCH(str_gmeanthresh);
+
+  return gh_double2scm(x);
+}
+
 GOOSE_PROC(covar, "realset-covar",
 	   2,0,0, (SCM scm_rs1, SCM scm_rs2))
 {
@@ -840,4 +857,4 @@ scm_init_realset()
 }
 
 
-// $Id: RealSet_smob.cpp,v 1.10 1999/05/28 17:05:05 trow Exp $
+// $Id: RealSet_smob.cpp,v 1.11 1999/07/09 19:45:15 trow Exp $
