@@ -1,12 +1,13 @@
 // This is -*- C++ -*-
-// $Id: Exception.h,v 1.2 1999/03/16 18:29:23 alstrup Exp $
+// $Id: Exception.h,v 1.4 1999/07/09 19:44:32 trow Exp $
 
 /* 
  * Exception.h
  *
- * Copyright (C) 1998 Asger Alstrup Nielsen
+ * Copyright (C) 1998, 1999 Asger Alstrup Nielsen
  *
- * Developed by Asger Alstrup Nielsen <alstrup@diku.dk>
+ * Developed by Asger Alstrup Nielsen <alstrup@diku.dk> and
+ * Jon Trowbridge <trow@emccta.com>.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -32,17 +33,53 @@
 using namespace std;
 
 // Base class for exceptions
+
 class Exception {
 public:
-  Exception(string const & s) : cause(s) 
-    { }
-  virtual ~Exception()
-    { }
-  virtual string const & what() const {
-    return cause;
-  }
+  Exception() : cause_("?") { }
+  Exception(string const & s) : cause_(s) { }
+
+  virtual ~Exception() { }
+
+  virtual string const & what() const { return cause_; }
+
+protected:
+  void set_cause(const string& s) { cause_ = s; }
+
 private:
-  string cause;
+  string cause_;
+};
+
+// Some useful types of exceptions
+
+class Exception_IndexOutOfBounds : public Exception {
+public:
+  Exception_IndexOutOfBounds(int ind, int low, int hi);
+};
+
+class Exception_MustBeNonZero : public Exception {
+public:
+  Exception_MustBeNonZero(const string& s);
+};
+
+class Exception_MustBePositive : public Exception {
+public:
+  Exception_MustBePositive(const string& s);
+};
+
+class Exception_IllegalSize : public Exception {
+public:
+  Exception_IllegalSize(int sz);
+};
+
+class Exception_SizesDoNotMatch : public Exception {
+public:
+  Exception_SizesDoNotMatch();
+};
+
+class Exception_InternalError : public Exception {
+public:
+  Exception_InternalError();
 };
 
 #endif
